@@ -3,7 +3,7 @@
 #' @return If successful, returns MIs for an individual. If unsuccessful, 
 #' returns NA.
 #' @keywords internal 
-return.mis <- function(fit){
+return.mis <- function(fit, elig_paths){
   zero_se  <- FALSE
   no_paths <- FALSE
   error    <- any(grepl("error", class(fit)))
@@ -15,9 +15,20 @@ return.mis <- function(fit){
   } 
   
   if (!error & !zero_se){
-    mis   <- tryCatch(modindices(fit, op = "~", 
-                                 standardized = FALSE,
-                                 sort. = FALSE), 
+    #commented out by lan 4.11.2019
+    #mis   <- tryCatch(modindices(fit, op = "~", 
+    #                             standardized = FALSE,
+    #                             sort. = FALSE), 
+    #                  error = function(e) e)
+    # 
+    lanMod <- function(fit, elig_paths){
+      mis0 <- modindices(fit, standardized = FALSE, sort. = FALSE)
+      mis0_idx <- paste0(mis0$lhs,mis0$op,mis0$rhs)
+      mis <- mis0[mis0_idx %in% elig_paths,]
+      return(mis)
+    }
+    
+    mis   <- tryCatch(lanMod(fit, elig_paths),
                       error = function(e) e)
     error <- any(grepl("error", class(mis)))
     if (error) mis <- NA 
