@@ -22,7 +22,8 @@ setup <- function (data,
                    lv_scores = "regression",       
                    lv_estimator = "miiv",            
                    lv_miiv_scaling  = "first.indicator", 
-                   lv_final_estimator = "miiv") {
+                   lv_final_estimator = "miiv",
+                   ms_allow) {
   
 
     
@@ -336,7 +337,8 @@ setup <- function (data,
   ts_list <- setupTransformData(
     ts_list   = ts_list,
     varLabels = varLabels,
-    ctrlOpts  = ctrlOpts
+    ctrlOpts  = ctrlOpts,
+    ms_allow  = ms_allow
   )
 
   #-------------------------------------------------------------#
